Documentation
¶
Index ¶
- type Machine
- type MachineArgs
- type MachineInput
- type MachineOutput
- func (o MachineOutput) AptConfig() apt.ConfigPtrOutput
- func (o MachineOutput) Connection() ssh.ConnectionOutput
- func (MachineOutput) ElementType() reflect.Type
- func (o MachineOutput) RunnerConfig() runner.ConfigPtrOutput
- func (o MachineOutput) ToMachineOutput() MachineOutput
- func (o MachineOutput) ToMachineOutputWithContext(ctx context.Context) MachineOutput
- func (o MachineOutput) Triggers() pulumi.ArrayOutput
- type MachineState
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Machine ¶
type Machine struct {
pulumi.CustomResourceState
AptConfig apt.ConfigPtrOutput `pulumi:"aptConfig"`
Connection ssh.ConnectionOutput `pulumi:"connection"`
RunnerConfig runner.ConfigPtrOutput `pulumi:"runnerConfig"`
Triggers pulumi.ArrayOutput `pulumi:"triggers"`
}
func GetMachine ¶
func GetMachine(ctx *pulumi.Context, name string, id pulumi.IDInput, state *MachineState, opts ...pulumi.ResourceOption) (*Machine, error)
GetMachine gets an existing Machine resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).
func NewMachine ¶
func NewMachine(ctx *pulumi.Context, name string, args *MachineArgs, opts ...pulumi.ResourceOption) (*Machine, error)
NewMachine registers a new resource with the given unique name, arguments, and options.
func (*Machine) ElementType ¶
func (*Machine) ToMachineOutput ¶
func (i *Machine) ToMachineOutput() MachineOutput
func (*Machine) ToMachineOutputWithContext ¶
func (i *Machine) ToMachineOutputWithContext(ctx context.Context) MachineOutput
type MachineArgs ¶
type MachineArgs struct {
AptConfig apt.ConfigPtrInput
Connection ssh.ConnectionInput
RunnerConfig runner.ConfigPtrInput
Triggers pulumi.ArrayInput
}
The set of arguments for constructing a Machine resource.
func (MachineArgs) ElementType ¶
func (MachineArgs) ElementType() reflect.Type
type MachineInput ¶
type MachineInput interface {
pulumi.Input
ToMachineOutput() MachineOutput
ToMachineOutputWithContext(ctx context.Context) MachineOutput
}
type MachineOutput ¶
type MachineOutput struct{ *pulumi.OutputState }
func (MachineOutput) AptConfig ¶ added in v0.42.0
func (o MachineOutput) AptConfig() apt.ConfigPtrOutput
func (MachineOutput) Connection ¶
func (o MachineOutput) Connection() ssh.ConnectionOutput
func (MachineOutput) ElementType ¶
func (MachineOutput) ElementType() reflect.Type
func (MachineOutput) RunnerConfig ¶
func (o MachineOutput) RunnerConfig() runner.ConfigPtrOutput
func (MachineOutput) ToMachineOutput ¶
func (o MachineOutput) ToMachineOutput() MachineOutput
func (MachineOutput) ToMachineOutputWithContext ¶
func (o MachineOutput) ToMachineOutputWithContext(ctx context.Context) MachineOutput
func (MachineOutput) Triggers ¶ added in v0.46.0
func (o MachineOutput) Triggers() pulumi.ArrayOutput
type MachineState ¶
type MachineState struct {
}
func (MachineState) ElementType ¶
func (MachineState) ElementType() reflect.Type
Click to show internal directories.
Click to hide internal directories.